kedro.runner.run_node — Kedro 0.17.6 documentation

# kedro.runner.run_node

`kedro.runner.` `run_node`(node, catalog, is_async=False, run_id=None)

  Run a single Node with inputs from and outputs to the catalog.

  Parameters

    - node (`Node`) – The `Node` to run.

    - catalog (`DataCatalog`) – A `DataCatalog` containing the node’s inputs and outputs.

    - is_async (`bool`) – If True, the node inputs and outputs are loaded and saved asynchronously with threads. Defaults to False.

    - run_id (`Optional`[`str`]) – The id of the pipeline run

  Return type

    `Node`

  Returns

    The node argument.